@@ -3,8 +3,9 @@ import re
 import argparse
 import math
 
-__version__ = '0.5.1'
+__version__ = '0.6'
 
+HEX_SHORT = re.compile('^[0-9A-Fa-f]{3}(?::\\d+(?:\\.\\d+)?)?$')
 HEX_COMP3 = re.compile('^[0-9A-Fa-f]{6}(?::\\d+(?:\\.\\d+)?)?$')
 HEX_COMP4 = re.compile('^[0-9A-Fa-f]{8}$')
 DEC_COMP3 = re.compile('^\\[\\d+(,\\d+){2}\\](?::\\d+(?:\\.\\d+)?)?$')
@@ -20,6 +21,10 @@ def from_hex(number):
     return int(number, 16)
 
 
+def from_short_hex(number):
+    return int(number, 16) * 17
+
+
 def to_argb_hex(color):
     return '{:02x}{:02x}{:02x}{:02x}'.format(color[3], *color[:3])
 
@@ -41,6 +46,15 @@ def from_rgb_hex(s):
     return tuple(map(from_hex, [r, g, b])) + (a,)
 
 
+def from_rgb_short_hex(s):
+    r, g, b = s[0], s[1], s[2]
+    a = 255
+    if len(s) > 3:
+        s = s[4:]
+        a = int(round(float(s) * 255))
+    return tuple(map(from_short_hex, [r, g, b])) + (a,)
+
+
 def from_argb_hex(s):
     a, r, g, b = s[0:2], s[2:4], s[4:6], s[6:8]
     return tuple(map(from_hex, [r, g, b, a]))
@@ -106,6 +120,8 @@ def blend(gamma, *colors):
 def parse_color(argb, str_):
     if str_ in STD_COLORS:
         return STD_COLORS[str_]
+    if HEX_SHORT.match(str_):
+        return from_rgb_short_hex(str_)
     if HEX_COMP3.match(str_):
         return from_rgb_hex(str_)
     if HEX_COMP4.match(str_):
@@ -157,15 +173,17 @@ def main():
         metavar='COLOR',
         help=(
             'color in following formats\n\n'
+            'RGB\n'
+            'RGB:opacity\n'
             'RRGGBB\n'
-            'RRGGBB:p\n'
+            'RRGGBB:opacity\n'
             'RRGGBBAA\n'
             '[r,g,b]\n'
-            '[r,g,b]:p\n'
+            '[r,g,b]:opacity\n'
             '[r,g,b,a]\n'
             'white or black\n\n'
             'where R, G, B, A are hexadecimal digits\n'
-            '      p is opacity in the range [0, 1]\n'
+            '      opacity is in the range [0, 1]\n'
             '      r, g, b, a are are decimal values in the range [0, 255]'))
     parser.add_argument(
         '--argb',
